@@ -30,7 +30,7 @@ If there is no parent span and the service name is not overridden the agent will
 from ...utils.importlib import require_modules
 
 
-required_modules = ['jinja2']
+required_modules = ["jinja2"]
 
 with require_modules(required_modules) as missing_modules:
     if not missing_modules:
@@ -38,6 +38,6 @@ with require_modules(required_modules) as missing_modules:
         from .patch import unpatch
 
         __all__ = [
-            'patch',
-            'unpatch',
+            "patch",
+            "unpatch",
         ]
