@@ -17,18 +17,19 @@ from typing import Union
 
 from ddtrace import config
 from ddtrace.filters import TraceFilter
+from ddtrace.utils.deprecation import deprecation
 from ddtrace.vendor import debtcollector
 
 from . import _hooks
+from .constants import AUTO_KEEP
+from .constants import AUTO_REJECT
 from .constants import ENV_KEY
 from .constants import FILTERS_KEY
 from .constants import HOSTNAME_KEY
+from .constants import PID
 from .constants import SAMPLE_RATE_METRIC_KEY
 from .constants import VERSION_KEY
 from .context import Context
-from .ext import system
-from .ext.priority import AUTO_KEEP
-from .ext.priority import AUTO_REJECT
 from .internal import agent
 from .internal import atexit
 from .internal import compat
@@ -48,6 +49,7 @@ from .internal.runtime import get_runtime_id
 from .internal.writer import AgentWriter
 from .internal.writer import LogWriter
 from .internal.writer import TraceWriter
+from .monkey import patch
 from .provider import DefaultContextProvider
 from .sampler import BasePrioritySampler
 from .sampler import BaseSampler
@@ -71,6 +73,8 @@ DD_LOG_FORMAT = "%(asctime)s %(levelname)s [%(name)s] [%(filename)s:%(lineno)d]
 )
 if debug_mode and not hasHandlers(log) and call_basic_config:
     if config.logs_injection:
+        # We need to ensure logging is patched in case the tracer logs during initialization
+        patch(logging=True)
         logging.basicConfig(level=logging.DEBUG, format=DD_LOG_FORMAT)
     else:
         logging.basicConfig(level=logging.DEBUG)
@@ -143,10 +147,21 @@ class Tracer(object):
                 sync_mode=self._use_sync_mode(),
             )
         self.writer = writer  # type: TraceWriter
-        self._partial_flush_enabled = asbool(get_env("tracer", "partial_flush_enabled", default=False))
+
+        # DD_TRACER_... should be deprecated after version 1.0.0 is released
+        pfe_default_value = False
+        pfms_default_value = 500
+        if "DD_TRACER_PARTIAL_FLUSH_ENABLED" in os.environ or "DD_TRACER_PARTIAL_FLUSH_MIN_SPANS" in os.environ:
+            deprecation("DD_TRACER_... use DD_TRACE_... instead", version="1.0.0")
+            pfe_default_value = asbool(get_env("tracer", "partial_flush_enabled", default=pfe_default_value))
+            pfms_default_value = int(
+                get_env("tracer", "partial_flush_min_spans", default=pfms_default_value)  # type: ignore[arg-type]
+            )
+        self._partial_flush_enabled = asbool(get_env("trace", "partial_flush_enabled", default=pfe_default_value))
         self._partial_flush_min_spans = int(
-            get_env("tracer", "partial_flush_min_spans", default=500)  # type: ignore[arg-type]
+            get_env("trace", "partial_flush_min_spans", default=pfms_default_value)  # type: ignore[arg-type]
         )
+
         self._initialize_span_processors()
         self._hooks = _hooks.Hooks()
         atexit.register(self._atexit)
@@ -585,7 +600,7 @@ class Tracer(object):
 
         if not span._parent:
             span.meta["runtime-id"] = get_runtime_id()
-            span.metrics[system.PID] = self._pid
+            span.metrics[PID] = self._pid
 
         # Apply default global tags.
         if self.tags:
@@ -623,9 +638,6 @@ class Tracer(object):
 
     def _on_span_finish(self, span):
         # type: (Span) -> None
-        if self.log.isEnabledFor(logging.DEBUG):
-            self.log.debug("finishing span %s (enabled:%s)", span.pprint(), self.enabled)
-
         active = self.current_span()
         # Debug check: if the finishing span has a parent and its parent
         # is not the next active span then this is an error in synchronous tracing.
@@ -640,6 +652,9 @@ class Tracer(object):
         for p in self._span_processors:
             p.on_span_finish(span)
 
+        if self.log.isEnabledFor(logging.DEBUG):
+            self.log.debug("finishing span %s (enabled:%s)", span.pprint(), self.enabled)
+
     def _initialize_span_processors(self):
         # type: () -> None
         trace_processors = []  # type: List[TraceProcessor]
